==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/view_rozdeleni_dv_form.php <==
<?php
/**
 * pavel.rudol, 21.10.2019
 * Zobrazeni formulare rozdelenidvform.php - editace rozdeleni dennich vysledku pro obdobi
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;

/** @var RozdeleniDVForm $this */

$pocetDnu = DateUtils::daysBetween($this ->datumOd, $this ->datumDo) + 1;
$pocetRadku = count($this ->radky);
$default = 'defaultfocus';

?>

<?php if ($this ->renderHtmlForm) { ?><form method="post"><?php } ?>
<div class="rozdeleniDV" data-idpp="<?= $this ->pp ->idPP ?>" data-datum-od="<?= DateUtils::dateToUrlString($this ->datumOd) ?>" data-datum-do="<?= DateUtils::dateToUrlString($this ->datumDo) ?>" data-count="<?= $pocetRadku ?>">
    <?php if (!$this ->readOnly) { ?>
    <input type="hidden" name="osoba" value="<?= $this ->pp ->idPP ?>" />
    <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->datumOd) ?>" />
    <input type="hidden" name="rozdelenidv_rows_count" value="<?= $pocetRadku ?>" />
    <input type="hidden" name="deleteRowIndex" id="deleteRowIndex" value="" />
    <input type="hidden" name="remainRowIndex" id="remainRowIndex" value="" />
    <?php } ?>

    <table class="browser keyInputMove oddEvenRows grid input-grid-form">
        <thead>
            <tr>
                <!-- hlavicka -->
                <th>
                    <?= StringUtils::htmlTextConvert($this ->typRozdeleni ->popis) ?>
                </th>
                <th>
                    <?= \Ron\ronText('Casova_slozka') ?>
                </th>
                <!-- dny -->
                <?php for ($datum = $this ->datumOd;  $datum <= $this ->datumDo;  $datum = DateUtils::incDayStart($datum)) { ?>
                    <th class="align-center<?= ($datum == $this ->datumDo) ? ' border-right' : '' ?>"><?= date('j.n.', $datum) ?></th>
                <?php } ?>

                <th class="align-right soucet"><?= \Ron\ronText('Celkem') ?></th>
                <?php if (!$this ->readOnly) { ?>
                <th class="tlacitka"></th>
                <?php } ?>
            </tr>
        </thead>

        <?php if ($this ->schvaleni ->jeSchvaleno($this ->datumOd)) { ?>
            <tbody id="schvaleni_dochazky">
                <tr>
                    <td colspan="2" class="border-right"></td>
                    <?php for ($datum = $this ->datumOd;  $datum <= $this ->datumDo;  $datum = DateUtils::incDayStart($datum)) { ?>
                        <td class="schvaleni <?= $this ->schvaleni ->classNejvyssiUroven($datum) ?><?= ($datum == $this ->datumDo) ? ' border-right' : '' ?>"></td>
                    <?php } ?>
                    <td></td>
                    <?php if (!$this ->readOnly) { ?><td class="tlacitka"></td><?php } ?>
                </tr>
            </tbody>
        <?php } ?>

        <!-- data -->
        <tbody class="border-bottom">
            <?php
                $celkovySoucet = 0;
                foreach ($this ->radky as $cisloRadku => $radek) { ?>
                <tr data-rowindex="<?= $cisloRadku ?>">
                    <?php
                        echo '<td class="rozdeleni" title="' . $radek ->popisRozdeleni . '">';
                        $this ->renderInputRozdeleni($radek, $cisloRadku);
                        echo '</td>';

                        echo '<td class="casova_slozka" title="' . $radek ->popisCasoveSlozky . '">';
                        $this ->renderInputCasoveSlozky($radek, $cisloRadku);
                        echo '</td>';


                    $soucet = 0;
                    for ($datum = $this ->datumOd, $i = 0;  $datum <= $this ->datumDo;  $datum = DateUtils::incDayStart($datum), $i++)
                    {
                        $zaznam = $radek->zaznamy[$i];

                        $class = (($this ->chybySloupcu[$i] || ($zaznam && $zaznam->error_hodiny)) ? 'error-back' : '') . (($datum == $this ->datumDo) ? ' border-right' : '');

                        if ($zaznam && $zaznam->rozdeleniSchvaleno) {
                            $class .= ' ' . 'rozdelenidv_schvaleno';
                        }

                        $soucet += isset($zaznam) ? $zaznam ->hodiny : 0;
                        ?>
                        <td class="position-relative <?= $class ?>">

                            <input name="hodnota_<?= $cisloRadku ?>_<?= $i ?>" id="hodnota_<?= $cisloRadku ?>_<?= $i ?>"
                                   class="rozdelenidv_hodiny form-input align-right position-relative inputTime <?= $default ?> <?= MessageManager::getInstance()->getClass("hodnota_{$cisloRadku}_{$i}") ?>"
                                   maxlength="5" value="<?= isset($zaznam) ? StringUtils::htmlTextConvert($zaznam ->hodinyStr) : '' ?>"
                                   data-datum="<?= StringUtils::format('date', $datum) ?>"
                                   <?php if ($this ->readOnly || !$this ->lzeEditovatZaznam($radek, $i)) { ?>readonly="readonly"<?php } ?>
                                   data-index="<?= $i ?>"
                                   title="<?= ($zaznam  &&  $zaznam->error_hodiny) ? $zaznam->error_hodiny : '' ?>"
                                />
                        </td>
                    <?php
                        $default = '';
                    }
                    $celkovySoucet += $soucet;
                    ?>
                    <td id="celkem_<?= $cisloRadku ?>" class="align-right">
                        <?= StringUtils::format('minuty', round($soucet * 60)) ?>
                        <?php if ($radek ->novyRadek) { ?><input type="hidden" name="novyRadek_<?= $cisloRadku ?>" value="1" /><?php } ?>
                    </td>
                    <?php if (!$this ->readOnly) { ?>
                    <td class="tlacitka no-wrap">
                        <i class="inline-glyph glyph-button fa glyph-square-left rozdelenidv_remain_row" title="<?= \Ron\ronText('Rozdeleni_dv_doplnit_odpracovanou') ?>" data-ron-confirm-text="<?= \Ron\ronText('Rozdeleni_dv_doplnit_odpracovanou_potvrzeni') ?>"
                           data-row-index="<?= $cisloRadku ?>"></i>

                        <?php if (Prava::jsouNejakePrava('schval_rozdeleni_dv')) { ?>
                            <i class='inline-glyph glyph-button fa glyph-approve rozdeleni_dv_schvalit' data-rozdeleni='<?= $radek->rozdeleni ?>' title='<?= \Ron\ronText('Schvalit_rozdeleni') ?>'></i>
                        <?php } ?>

                        <i class="inline-glyph glyph-button fa glyph-delete rozdelenidv_delete_row" title="<?= \Ron\ronText('Smazat_cely_radek') ?>" data-ron-confirm-text="<?= \Ron\ronText('Opravdu_smazat_cely_radek') ?>" data-row-index="<?= $cisloRadku ?>"></i>
                    </td>
                    <?php } ?>
                </tr>
            <?php } ?>
        </tbody>

        <!-- paticka -->
        <tbody>
            <tr data-index="SUM" class="browserfooter">
                <td colspan="2" class="border-right"><?= \Ron\ronText('Celkem') ?></td>
                <?php for ($i = 0;  $i < $pocetDnu;  $i++) { ?>
                    <td class="align-right<?= ($i == $pocetDnu - 1) ? ' border-right' : '' ?><?= $this ->chybySloupcu[$i] ? ' error-back' : '' ?>"
                        id="rozdeleniVysledku_sum_<?= $i ?>"><?= StringUtils::format('minuty', round($this->soucty[$i] * 60)) ?>
                    </td>
                <?php } ?>
                <td>
                    <?= StringUtils::format('minuty', round($celkovySoucet * 60)) ?>
                </td>
                <?php if (!$this ->readOnly) { ?>
                <td class="tlacitka"></td>
                <?php } ?>
            </tr>
            <tr data-index="DV" class="browserfooter font-weight-normal border-bottom">
                <td colspan="2" class="border-right"><?= \Ron\ronText('Celkem_rozdelit') ?></td>
                <?php
                $soucetOdpracovano = 0;
                for ($i = 0;  $i < $pocetDnu;  $i++) { ?>
                    <td class="align-right<?= ($i == $pocetDnu - 1) ? ' border-right' : '' ?><?= $this ->chybySloupcu[$i] ? ' error-back' : '' ?>"
                        id="rozdeleniVysledku_rozdelit_<?= $i ?>"><?= StringUtils::format('minuty', round($this->odpracovano[$i] * 60)) ?>
                    </td>
                <?php
                    $soucetOdpracovano += $this->odpracovano[$i];
                } ?>
                <td>
                    <?= StringUtils::format('minuty', round($soucetOdpracovano * 60)) ?>
                </td>
                <?php if (!$this ->readOnly) { ?>
                <td class="tlacitka"></td>
                <?php } ?>
            </tr>
            <tr data-index="ZBYVA" class="browserfooter font-weight-normal">
                <td colspan="2" class="border-right"><?= \Ron\ronText('Zbyva_rozdelit') ?></td>
                <?php
                $soucetRozdilu = 0;
                for ($i = 0;  $i < $pocetDnu;  $i++) {
                    $rozdil = $this->odpracovano[$i] - $this->soucty[$i];
                    ?>
                    <td class="align-right<?= ($i == $pocetDnu - 1) ? ' border-right' : '' ?><?= round(($rozdil * 60) < 0 ? ' minus' : '') ?><?= $this ->chybySloupcu[$i] ? ' error-back' : '' ?>"
                        id="rozdeleniVysledku_zbyva_<?= $i ?>">
                        <?= round($rozdil * 60) ? StringUtils::format('minuty', round($rozdil * 60)) : '' ?>
                    </td>
                <?php
                    $soucetRozdilu += $rozdil;
                }
                ?>
                <td>
                    <?= StringUtils::format('minuty', round($soucetRozdilu * 60)) ?>
                </td>
                <?php if (!$this ->readOnly) { ?>
                <td class="tlacitka"></td>
                <?php } ?>
            </tr>
        </tbody>
    </table>

    <?php if (!$this ->readOnly) { ?>
        <div>
            <?php if (RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) { ?>
                <span class='js' id='rozdelenidv_vyberrozdeleni' data-idpp='<?= $this ->pp ->idPP ?>'><?= \Ron\ronText('Rozdeleni_dv_vybrat_rozdeleni')  ?></span>
            <?php } ?>
        </div>

        <div class="buttons">
            <input type="submit" class="submitbutton" value="<?= \Ron\ronText('form.Store') ?>" />
            <input type="submit" class="submitbutton" name="novyRadek" value="<?= \Ron\ronText('Novy_radek') ?>" />
            <input type="submit" class="button" name="doplnitRadky" value="<?= \Ron\ronText('Doplnit_radky_editace_dv') ?>" title="<?= \Ron\ronText('Doplnit_radky_editace_dv_info') ?>"/>
        </div>
    <?php } ?>
</div>
<?php if ($this ->renderHtmlForm) { ?></form><?php } ?>

<?php
    if (RonPortalSettings::getPouzivatRozdeleniDV() && RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) {
    /** @noinspection PhpUnusedLocalVariableInspection */
    $typrozdeleni = $this ->typRozdeleni;

    require('view/rozdeleniosoby.php');
    ?>
<?php } ?>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/editace/view_rozdeleni_dv_form.php <==
<?php
/**
 * pavel.rudol, 21.10.2019
 * Zobrazeni formulare rozdelenidvform.php - editace rozdeleni dennich vysledku pro obdobi
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;

/** @var RozdeleniDVForm $this */

$pocetDnu = DateUtils::daysBetween($this ->datumOd, $this ->datumDo) + 1;
$pocetRadku = count($this ->radky);
$default = 'defaultfocus';

?>

<?php if ($this ->renderHtmlForm) { ?><form method="post"><?php } ?>
<div class="rozdeleniDV" data-idpp="<?= $this ->pp ->idPP ?>" data-datum-od="<?= DateUtils::dateToUrlString($this ->datumOd) ?>" data-datum-do="<?= DateUtils::dateToUrlString($this ->datumDo) ?>" data-count="<?= $pocetRadku ?>">
    <?php if (!$this ->readOnly) { ?>
    <input type="hidden" name="osoba" value="<?= $this ->pp ->idPP ?>" />
    <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->datumOd) ?>" />
    <input type="hidden" name="rozdelenidv_rows_count" value="<?= $pocetRadku ?>" />
    <input type="hidden" name="deleteRowIndex" id="deleteRowIndex" value="" />
    <input type="hidden" name="remainRowIndex" id="remainRowIndex" value="" />
    <?php } ?>

    <table class="browser keyInputMove oddEvenRows grid input-grid-form">
        <thead>
            <tr>
                <!-- hlavicka -->
                <th>
                    <?= StringUtils::htmlTextConvert($this ->typRozdeleni ->popis) ?>
                </th>
                <th>
                    <?= \Ron\ronText('Casova_slozka') ?>
                </th>
                <!-- dny -->
                <?php for ($datum = $this ->datumOd;  $datum <= $this ->datumDo;  $datum = DateUtils::incDayStart($datum)) { ?>
                    <th class="align-center<?= ($datum == $this ->datumDo) ? ' border-right' : '' ?>"><?= date('j.n.', $datum) ?></th>
                <?php } ?>

                <th class="align-right soucet"><?= \Ron\ronText('Celkem') ?></th>
                <?php if (!$this ->readOnly) { ?>
                <th class="tlacitka"></th>
                <?php } ?>
            </tr>
        </thead>

        <?php if ($this ->schvaleni ->jeSchvaleno($this ->datumOd)) { ?>
            <tbody id="schvaleni_dochazky">
                <tr>
                    <td colspan="2" class="border-right"></td>
                    <?php for ($datum = $this ->datumOd;  $datum <= $this ->datumDo;  $datum = DateUtils::incDayStart($datum)) { ?>
                        <td class="schvaleni <?= $this ->schvaleni ->classNejvyssiUroven($datum) ?><?= ($datum == $this ->datumDo) ? ' border-right' : '' ?>"></td>
                    <?php } ?>
                    <td></td>
                    <?php if (!$this ->readOnly) { ?><td class="tlacitka"></td><?php } ?>
                </tr>
            </tbody>
        <?php } ?>

        <!-- data -->
        <tbody class="border-bottom">
            <?php
                $celkovySoucet = 0;
                foreach ($this ->radky as $cisloRadku => $radek) { ?>
                <tr data-rowindex="<?= $cisloRadku ?>">
                    <?php
                        echo '<td class="rozdeleni" title="' . $radek ->popisRozdeleni . '">';
                        $this ->renderInputRozdeleni($radek, $cisloRadku);
                        echo '</td>';

                        echo '<td class="casova_slozka" title="' . $radek ->popisCasoveSlozky . '">';
                        $this ->renderInputCasoveSlozky($radek, $cisloRadku);
                        echo '</td>';


                    $soucet = 0;
                    for ($datum = $this ->datumOd, $i = 0;  $datum <= $this ->datumDo;  $datum = DateUtils::incDayStart($datum), $i++)
                    {
                        $zaznam = $radek->zaznamy[$i];

                        $class = (($this ->chybySloupcu[$i] || ($zaznam && $zaznam->error_hodiny)) ? 'error-back' : '') . (($datum == $this ->datumDo) ? ' border-right' : '');

                        if ($zaznam && $zaznam->rozdeleniSchvaleno) {
                            $class .= ' ' . 'rozdelenidv_schvaleno';
                        }

                        $soucet += isset($zaznam) ? $zaznam ->hodiny : 0;
                        ?>
                        <td class="position-relative <?= $class ?>">

                            <input name="hodnota_<?= $cisloRadku ?>_<?= $i ?>" id="hodnota_<?= $cisloRadku ?>_<?= $i ?>"
                                   class="rozdelenidv_hodiny form-input align-right position-relative inputTime <?= $default ?> <?= MessageManager::getInstance()->getClass("hodnota_{$cisloRadku}_{$i}") ?>"
                                   maxlength="5" value="<?= isset($zaznam) ? StringUtils::htmlTextConvert($zaznam ->hodinyStr) : '' ?>"
                                   data-datum="<?= StringUtils::format('date', $datum) ?>"
                                   <?php if ($this ->readOnly || !$this ->lzeEditovatZaznam($radek, $i)) { ?>readonly="readonly"<?php } ?>
                                   data-index="<?= $i ?>"
                                   title="<?= ($zaznam  &&  $zaznam->error_hodiny) ? $zaznam->error_hodiny : '' ?>"
                                />
                        </td>
                    <?php
                        $default = '';
                    }
                    $celkovySoucet += $soucet;
                    ?>
                    <td id="celkem_<?= $cisloRadku ?>" class="align-right">
                        <?= StringUtils::format('minuty', round($soucet * 60)) ?>
                        <?php if ($radek ->novyRadek) { ?><input type="hidden" name="novyRadek_<?= $cisloRadku ?>" value="1" /><?php } ?>
                    </td>
                    <?php if (!$this ->readOnly) { ?>
                    <td class="tlacitka no-wrap">
                        <i class="inline-glyph glyph-button fa glyph-square-left rozdelenidv_remain_row" title="<?= \Ron\ronText('Rozdeleni_dv_doplnit_odpracovanou') ?>" data-ron-confirm-text="<?= \Ron\ronText('Rozdeleni_dv_doplnit_odpracovanou_potvrzeni') ?>"
                           data-row-index="<?= $cisloRadku ?>"></i>

                        <?php if (Prava::jsouNejakePrava('schval_rozdeleni_dv')) { ?>
                            <i class='inline-glyph glyph-button fa glyph-approve rozdeleni_dv_schvalit' data-rozdeleni='<?= $radek->rozdeleni ?>' title='<?= \Ron\ronText('Schvalit_rozdeleni') ?>'></i>
                        <?php } ?>

                        <i class="inline-glyph glyph-button fa glyph-delete rozdelenidv_delete_row" title="<?= \Ron\ronText('Smazat_cely_radek') ?>" data-ron-confirm-text="<?= \Ron\ronText('Opravdu_smazat_cely_radek') ?>" data-row-index="<?= $cisloRadku ?>"></i>
                    </td>
                    <?php } ?>
                </tr>
            <?php } ?>
        </tbody>

        <!-- paticka -->
        <tbody>
            <tr data-index="SUM" class="browserfooter">
                <td colspan="2" class="border-right"><?= \Ron\ronText('Celkem') ?></td>
                <?php for ($i = 0;  $i < $pocetDnu;  $i++) { ?>
                    <td class="align-right<?= ($i == $pocetDnu - 1) ? ' border-right' : '' ?><?= $this ->chybySloupcu[$i] ? ' error-back' : '' ?>"
                        id="rozdeleniVysledku_sum_<?= $i ?>"><?= StringUtils::format('minuty', round($this->soucty[$i] * 60)) ?>
                    </td>
                <?php } ?>
                <td>
                    <?= StringUtils::format('minuty', round($celkovySoucet * 60)) ?>
                </td>
                <?php if (!$this ->readOnly) { ?>
                <td class="tlacitka"></td>
                <?php } ?>
            </tr>
            <?php if ($this ->casovaSlozkaSoucet) { ?>
            <tr data-index="DV" class="browserfooter font-weight-normal border-bottom">
                <td colspan="2" class="border-right"><?= \Ron\ronText('Celkem_rozdelit') ?></td>
                <?php
                $soucetOdpracovano = 0;
                for ($i = 0;  $i < $pocetDnu;  $i++) { ?>
                    <td class="align-right<?= ($i == $pocetDnu - 1) ? ' border-right' : '' ?><?= $this ->chybySloupcu[$i] ? ' error-back' : '' ?>"
                        id="rozdeleniVysledku_rozdelit_<?= $i ?>"><?= StringUtils::format('minuty', round($this->odpracovano[$i] * 60)) ?>
                    </td>
                <?php
                    $soucetOdpracovano += $this->odpracovano[$i];
                } ?>
                <td>
                    <?= StringUtils::format('minuty', round($soucetOdpracovano * 60)) ?>
                </td>
                <?php if (!$this ->readOnly) { ?>
                <td class="tlacitka"></td>
                <?php } ?>
            </tr>
            <tr data-index="ZBYVA" class="browserfooter font-weight-normal">
                <td colspan="2" class="border-right"><?= \Ron\ronText('Zbyva_rozdelit') ?></td>
                <?php
                $soucetRozdilu = 0;
                for ($i = 0;  $i < $pocetDnu;  $i++) {
                    $rozdil = $this->odpracovano[$i] - $this->soucty[$i];
                    ?>
                    <td class="align-right<?= ($i == $pocetDnu - 1) ? ' border-right' : '' ?><?= round($rozdil * 60) < 0 ? ' minus' : '' ?><?= $this ->chybySloupcu[$i] ? ' error-back' : '' ?>"
                        id="rozdeleniVysledku_zbyva_<?= $i ?>">
                        <?= round($rozdil * 60) ? StringUtils::format('minuty', round($rozdil * 60)) : '' ?>
                    </td>
                <?php
                    $soucetRozdilu += $rozdil;
                }
                ?>
                <td>
                    <?= StringUtils::format('minuty', round($soucetRozdilu * 60)) ?>
                </td>
                <?php if (!$this ->readOnly) { ?>
                <td class="tlacitka"></td>
                <?php } ?>
            </tr>
            <?php } ?>
        </tbody>
    </table>

    <?php if (!$this ->readOnly) { ?>
        <div>
            <?php if (RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) { ?>
                <span class='js' id='rozdelenidv_vyberrozdeleni' data-idpp='<?= $this ->pp ->idPP ?>'><?= \Ron\ronText('Rozdeleni_dv_vybrat_rozdeleni')  ?></span>
            <?php } ?>
        </div>

        <div class="buttons">
            <input type="submit" class="submitbutton" value="<?= \Ron\ronText('form.Store') ?>" />
            <input type="submit" class="submitbutton" name="novyRadek" value="<?= \Ron\ronText('Novy_radek') ?>" />
            <input type="submit" class="button" name="doplnitRadky" value="<?= \Ron\ronText('Doplnit_radky_editace_dv') ?>" title="<?= \Ron\ronText('Doplnit_radky_editace_dv_info') ?>"/>
        </div>
    <?php } ?>
</div>
<?php if ($this ->renderHtmlForm) { ?></form><?php } ?>

<?php
    if (RonPortalSettings::getPouzivatRozdeleniDV() && RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) {
    /** @noinspection PhpUnusedLocalVariableInspection */
    $typrozdeleni = $this ->typRozdeleni;
    /** @noinspection PhpUnusedLocalVariableInspection  Pouzito ve view */
    $url = '?menuid=editace&action=rozdeleniosoby&idpp=' . $this ->pp ->idPP;

    require('view/rozdeleniosoby.php');
    ?>
<?php } ?>
